==> jc-1.4.0.tar.gz: soot/tagkit/Base64.h <==
// public class soot.tagkit.Base64

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a167f3dc107f4cdb soot_tagkit_Base64

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_Base64_H_
#define _JC_soot_tagkit_Base64_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_Base64$sub_refs	_jc_soot_tagkit_Base64$sub_refs;
typedef struct _jc_soot_tagkit_Base64$sub_nonrefs	_jc_soot_tagkit_Base64$sub_nonrefs;
typedef struct _jc_soot_tagkit_Base64$refs	_jc_soot_tagkit_Base64$refs;
typedef struct _jc_soot_tagkit_Base64$nonrefs	_jc_soot_tagkit_Base64$nonrefs;
typedef struct _jc_soot_tagkit_Base64$object	_jc_soot_tagkit_Base64$object;

typedef struct _jc_soot_tagkit_Base64$fields_struct	_jc_soot_tagkit_Base64$fields_struct;
typedef const struct _jc_soot_tagkit_Base64$vmethods	_jc_soot_tagkit_Base64$vmethods;
typedef const struct _jc_soot_tagkit_Base64$vtable	_jc_soot_tagkit_Base64$vtable;
typedef const struct _jc_soot_tagkit_Base64$vtype	_jc_soot_tagkit_Base64$vtype;

// Class fields structure
struct _jc_soot_tagkit_Base64$fields_struct {
	_jc_char_array	*alphabet;
	_jc_byte_array	*codes;
};
extern _jc_soot_tagkit_Base64$fields_struct _jc_soot_tagkit_Base64$class_fields;

// Constructors
extern void _jc_soot_tagkit_Base64$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_Base64$object *);

// Static methods
extern void _jc_soot_tagkit_Base64$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern _jc_byte_array *_jc_soot_tagkit_Base64$method$decode$01e9cb82d83e32e6(_jc_env *, struct _jc_char_array *);
extern _jc_char_array *_jc_soot_tagkit_Base64$method$encode$2740c4c13cb6ae53(_jc_env *, struct _jc_byte_array *);

// Virtual methods structure
struct _jc_soot_tagkit_Base64$vmethods {
};

// Vtable
struct _jc_soot_tagkit_Base64$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_Base64$vmethods	soot_tagkit_Base64;
};

// Vtype
struct _jc_soot_tagkit_Base64$vtype {
	_jc_type			type;
	_jc_soot_tagkit_Base64$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_Base64$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_Base64$refs {
    _jc_soot_tagkit_Base64$sub_refs	soot_tagkit_Base64;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_Base64$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_Base64$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_Base64$sub_nonrefs	soot_tagkit_Base64;
};

// Object instance structure
struct _jc_soot_tagkit_Base64$object {
	_jc_soot_tagkit_Base64$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_Base64$vtype	*vtype;
	_jc_soot_tagkit_Base64$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_Base64$vtype _jc_soot_tagkit_Base64$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_Base64, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_Base64$class_object;

#endif	/* _JC_soot_tagkit_Base64_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/Base64.h <==
// public class soot.tagkit.Base64

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a167f3dc107f4cdb soot_tagkit_Base64

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_Base64_H_
#define _JC_soot_tagkit_Base64_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_Base64$sub_refs	_jc_soot_tagkit_Base64$sub_refs;
typedef struct _jc_soot_tagkit_Base64$sub_nonrefs	_jc_soot_tagkit_Base64$sub_nonrefs;
typedef struct _jc_soot_tagkit_Base64$refs	_jc_soot_tagkit_Base64$refs;
typedef struct _jc_soot_tagkit_Base64$nonrefs	_jc_soot_tagkit_Base64$nonrefs;
typedef struct _jc_soot_tagkit_Base64$object	_jc_soot_tagkit_Base64$object;

typedef struct _jc_soot_tagkit_Base64$fields_struct	_jc_soot_tagkit_Base64$fields_struct;
typedef const struct _jc_soot_tagkit_Base64$vmethods	_jc_soot_tagkit_Base64$vmethods;
typedef const struct _jc_soot_tagkit_Base64$vtable	_jc_soot_tagkit_Base64$vtable;
typedef const struct _jc_soot_tagkit_Base64$vtype	_jc_soot_tagkit_Base64$vtype;

// Class fields structure
struct _jc_soot_tagkit_Base64$fields_struct {
	_jc_char_array	*alphabet;
	_jc_byte_array	*codes;
};
extern _jc_soot_tagkit_Base64$fields_struct _jc_soot_tagkit_Base64$class_fields;

// Constructors
extern void _jc_soot_tagkit_Base64$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_Base64$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_tagkit_Base64$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_Base64$method$decode$01e9cb82d83e32e6(_jc_env *, struct _jc_char_array *) _JC_JCNI_ATTR;
extern _jc_char_array *_jc_soot_tagkit_Base64$method$encode$2740c4c13cb6ae53(_jc_env *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_tagkit_Base64$vmethods {
};

// Vtable
struct _jc_soot_tagkit_Base64$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_Base64$vmethods	soot_tagkit_Base64;
};

// Vtype
struct _jc_soot_tagkit_Base64$vtype {
	_jc_type			type;
	_jc_soot_tagkit_Base64$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_Base64$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_Base64$refs {
    _jc_soot_tagkit_Base64$sub_refs	soot_tagkit_Base64;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_Base64$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_Base64$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_Base64$sub_nonrefs	soot_tagkit_Base64;
};

// Object instance structure
struct _jc_soot_tagkit_Base64$object {
	_jc_soot_tagkit_Base64$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_Base64$vtype	*vtype;
	_jc_soot_tagkit_Base64$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_Base64$vtype _jc_soot_tagkit_Base64$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_Base64, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_Base64$class_object;

#endif	/* _JC_soot_tagkit_Base64_H_ */
